@@ -13,7 +13,7 @@ pub type Result<T> = std::result::Result<T, Error>;
 
 /// The error type for this library.
 #[derive(Debug, Snafu)]
-#[snafu(visibility = "pub(super)")]
+#[snafu(visibility(pub(super)))]
 #[non_exhaustive]
 #[allow(missing_docs)]
 pub enum Error {
